@@ -13,7 +13,7 @@ our @EXPORT_OK = (
 );
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = "v0.25.1";
+our $VERSION = "v0.26.0";
 
 1;
 __END__
@@ -263,7 +263,7 @@ L<https://rxjs.dev/api/index/const/NEVER>
 
 L<https://rxjs.dev/api/index/class/Observable>
 
-    0.578, 0.234, 0.678, ... (every 1 second)
+    # 0.578, 0.234, 0.678, ... (every 1 second)
     my $o = rx_observable->new(sub ($subscriber) {
         # your code goes here
         Mojo::IOLoop->recurring(1, sub {$subscriber->next(rand())});
@@ -290,6 +290,7 @@ L<https://rxjs.dev/api/index/function/race>
 
 L<https://rxjs.dev/api/index/class/Subject>
 
+    # 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, complete
     my $subject = rx_subject->new;
     $subject->subscribe($observer);
 
@@ -313,12 +314,12 @@ L<https://rxjs.dev/api/index/function/timer>
 
 Works like rxjs's "timer", except the parameter is in seconds instead of ms.
 
-    # (pause 10 seconds) 0, 1, 2, 3, ... (every 1 second)
-    rx_timer(10, 1)->subscribe($observer);
-
     # (pause 10 seconds) 0, complete
     rx_timer(10)->subscribe($observer);
 
+    # (pause 10 seconds) 0, 1, 2, 3, ... (every 1 second)
+    rx_timer(10, 1)->subscribe($observer);
+
 =back
 
 =head2 PIPEABLE OPERATORS
@@ -436,6 +437,11 @@ L<https://rxjs.dev/api/operators/filter>
         op_filter(sub {$_[0] % 2 == 0}),
     )->subscribe($observer);
 
+    # 10, 36, 50
+    rx_of(10, 22, 36, 41, 50, 73)->pipe(
+        op_filter(sub ($v, $idx) { $idx % 2 == 0 }),
+    )->subscribe($observer);
+
 =item op_finalize
 
 L<https://rxjs.dev/api/operators/finalize>
@@ -468,6 +474,11 @@ L<https://rxjs.dev/api/operators/map>
         op_map(sub {$_[0] + 10}),
     )->subscribe($observer);
 
+    # 10-0, 20-1, 30-2, complete
+    rx_of(10, 20, 30)->pipe(
+        op_map(sub ($v, $idx) { "$v-$idx" }),
+    )->subscribe($observer);
+
 =item op_map_to
 
 L<https://rxjs.dev/api/operators/mapTo>
@@ -525,6 +536,15 @@ L<https://rxjs.dev/api/operators/pluck>
 
 L<https://rxjs.dev/api/operators/refCount>
 
+=item op_sample_time
+
+L<https://rxjs.dev/api/operators/sampleTime>
+
+    # 0, 2, 3, 5, 6, 8, ...
+    rx_interval(1)->pipe(
+        op_sample_time(1.6),
+    )->subscribe($observer);
+
 =item op_scan
 
 L<https://rxjs.dev/api/operators/scan>
@@ -615,6 +635,18 @@ L<https://rxjs.dev/api/operators/tap>
         op_tap(sub {say "foo$_[0]"}),
     )->subscribe($observer);
 
+=item op_throttle_time
+
+L<https://rxjs.dev/api/operators/throttleTime>
+
+At the moment, this function does not accept the configuration options that
+rxjs's throttleTime accepts. Only the first parameter (duration) is taken into account.
+
+    # 0, 3, 6, 9, 12, ...
+    rx_interval(1)->pipe(
+        op_throttle_time(2.1),
+    )->subscribe($observer);
+
 =item op_with_latest_from
 
 L<https://rxjs.dev/api/operators/withLatestFrom>
